django_analyses.models.output.types package — django_analyses 0.0.3 documentation

# django_analyses.models.output.types package

## Submodules

## django_analyses.models.output.types.file_output module

class `django_analyses.models.output.types.file_output.` `FileOutput`(id, run, output_ptr, value, definition)

  Bases: `django_analyses.models.output.output.Output`

  exception `DoesNotExist`

    Bases: `django_analyses.models.output.output.Output.DoesNotExist`

  exception `MultipleObjectsReturned`

    Bases: `django_analyses.models.output.output.Output.MultipleObjectsReturned`

  `definition`

    Accessor to the related object on the forward side of a many-to-one or one-to-one (via ForwardOneToOneDescriptor subclass) relation.

    In the example:

        class Child(Model):
            parent = ForeignKey(Parent, related_name='children')

    `Child.parent` is a `ForwardManyToOneDescriptor` instance.

  `definition_id`
  `get_type`() → str
  `output_ptr`

    Accessor to the related object on the forward side of a one-to-one relation.

    In the example:

        class Restaurant(Model):
            place = OneToOneField(Place, related_name='restaurant')

    `Restaurant.place` is a `ForwardOneToOneDescriptor` instance.

  `output_ptr_id`
  `pre_save`() → None
  `raise_missing_output_error`() → None
  `validate`() → None
  `value`

    A wrapper for a deferred-loading field. When the value is read from this object the first time, the query is executed.

## django_analyses.models.output.types.float_output module

class `django_analyses.models.output.types.float_output.` `FloatOutput`(id, run, output_ptr, value, definition)

  Bases: `django_analyses.models.output.output.Output`

  exception `DoesNotExist`

    Bases: `django_analyses.models.output.output.Output.DoesNotExist`

  exception `MultipleObjectsReturned`

    Bases: `django_analyses.models.output.output.Output.MultipleObjectsReturned`

  `definition`

    Accessor to the related object on the forward side of a many-to-one or one-to-one (via ForwardOneToOneDescriptor subclass) relation.

    In the example:

        class Child(Model):
            parent = ForeignKey(Parent, related_name='children')

    `Child.parent` is a `ForwardManyToOneDescriptor` instance.

  `definition_id`
  `get_type`() → str
  `output_ptr`

    Accessor to the related object on the forward side of a one-to-one relation.

    In the example:

        class Restaurant(Model):
            place = OneToOneField(Place, related_name='restaurant')

    `Restaurant.place` is a `ForwardOneToOneDescriptor` instance.

  `output_ptr_id`
  `value`

    A wrapper for a deferred-loading field. When the value is read from this object the first time, the query is executed.

## django_analyses.models.output.types.output_types module

class `django_analyses.models.output.types.output_types.` `OutputTypes`

  Bases: `enum.Enum`

  An enumeration.

  `FIL` = 'File'
  `FLT` = 'Float'

## Module contents